==> haskell-x11-1.6.1.2-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.6.1.2
id: X11-1.6.1.2-ftRHY7lb0w8loAPqJM9vJ
key: X11-1.6.1.2-ftRHY7lb0w8loAPqJM9vJ
license: BSD3
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/haskell-pkg-janitors/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library.
    The binding is a direct translation of the C binding; for
    documentation of these calls, refer to "The Xlib Programming
    Manual", available online at <http://tronche.com/gui/x/xlib/>.
category: Graphics
exposed: True
exposed-modules:
    Graphics.X11 Graphics.X11.Types Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Font Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Extras
    Graphics.X11.Xinerama Graphics.X11.Xrandr Graphics.X11.XScreenSaver
    Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault
hidden-modules: Graphics.X11.Xlib.Internal
abi: 4a07b283b020a6f97bff26f2ed1e969f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/X11-1.6.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/X11-1.6.1.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/X11-1.6.1.2
hs-libraries: HSX11-1.6.1.2-ftRHY7lb0w8loAPqJM9vJ
extra-libraries:
    Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-8.0.1/site-local/X11-1.6.1.2/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.9.0.0 data-default-0.7.1.1-IrbTxn4APE83ZiDGILskO
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-1.6.1.2-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.6.1.2
id: X11-1.6.1.2-FaJ9HH6jFQJJi1uDWovFSr
key: X11-1.6.1.2-FaJ9HH6jFQJJi1uDWovFSr
license: BSD3
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/haskell-pkg-janitors/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library.
    The binding is a direct translation of the C binding; for
    documentation of these calls, refer to "The Xlib Programming
    Manual", available online at <http://tronche.com/gui/x/xlib/>.
category: Graphics
exposed: True
exposed-modules:
    Graphics.X11 Graphics.X11.Types Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Font Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Extras
    Graphics.X11.Xinerama Graphics.X11.Xrandr Graphics.X11.XScreenSaver
    Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault
hidden-modules: Graphics.X11.Xlib.Internal
abi: 8b2bf390c493a238117fc3c9b656363c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/X11-1.6.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/X11-1.6.1.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/X11-1.6.1.2
hs-libraries: HSX11-1.6.1.2-FaJ9HH6jFQJJi1uDWovFSr
extra-libraries:
    Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-8.0.1/site-local/X11-1.6.1.2/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.9.0.0 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
